@@ -30,11 +30,11 @@ Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 #include "bgpd/bgp_aspath.h"
 
 /* Hash of community attribute. */
-struct hash *ecomhash;
+static struct hash *ecomhash;
 
 /* Allocate a new ecommunities.  */
-struct ecommunity *
-ecommunity_new ()
+static struct ecommunity *
+ecommunity_new (void)
 {
   return (struct ecommunity *) XCALLOC (MTYPE_ECOMMUNITY,
 					sizeof (struct ecommunity));
@@ -97,7 +97,7 @@ ecommunity_add_val (struct ecommunity *ecom, struct ecommunity_val *eval)
 
 /* This function takes pointer to Extended Communites strucutre then
    create a new Extended Communities structure by uniq and sort each
-   Exteneded Communities value.  */
+   Extended Communities value.  */
 static struct ecommunity *
 ecommunity_uniq_sort (struct ecommunity *ecom)
 {
@@ -108,7 +108,7 @@ ecommunity_uniq_sort (struct ecommunity *ecom)
   if (! ecom)
     return NULL;
   
-  new = ecommunity_new ();;
+  new = ecommunity_new ();
   
   for (i = 0; i < ecom->size; i++)
     {
@@ -262,6 +262,13 @@ ecommunity_init (void)
 {
   ecomhash = hash_create (ecommunity_hash_make, ecommunity_cmp);
 }
+
+void
+ecommunity_finish (void)
+{
+  hash_free (ecomhash);
+  ecomhash = NULL;
+}
 
 /* Extended Communities token enum. */
 enum ecommunity_token
@@ -673,7 +680,7 @@ ecommunity_ecom2str (struct ecommunity *ecom, int format)
 	  eas.val = (*pnt++ << 8);
 	  eas.val |= (*pnt++);
 
-	  len = sprintf( str_buf + str_pnt, "%s%d:%d", prefix,
+	  len = sprintf( str_buf + str_pnt, "%s%u:%d", prefix,
                         eas.as, eas.val );
 	  str_pnt += len;
 	  first = 0;
@@ -688,7 +695,7 @@ ecommunity_ecom2str (struct ecommunity *ecom, int format)
 	  eas.val |= (*pnt++ << 8);
 	  eas.val |= (*pnt++);
 
-	  len = sprintf (str_buf + str_pnt, "%s%d:%d", prefix,
+	  len = sprintf (str_buf + str_pnt, "%s%u:%d", prefix,
 			 eas.as, eas.val);
 	  str_pnt += len;
 	  first = 0;
