@@ -96,11 +96,9 @@ ospf6_interface_create (struct interface *ifp)
   unsigned int iobuflen;
 
   oi = (struct ospf6_interface *)
-    XMALLOC (MTYPE_OSPF6_IF, sizeof (struct ospf6_interface));
+    XCALLOC (MTYPE_OSPF6_IF, sizeof (struct ospf6_interface));
 
-  if (oi)
-    memset (oi, 0, sizeof (struct ospf6_interface));
-  else
+  if (!oi)
     {
       zlog_err ("Can't malloc ospf6_interface for ifindex %d", ifp->ifindex);
       return (struct ospf6_interface *) NULL;
@@ -827,7 +825,7 @@ ospf6_interface_show (struct vty *vty, struct interface *ifp)
   vty_out (vty, "  Number of I/F scoped LSAs is %u%s",
            oi->lsdb->count, VNL);
 
-  gettimeofday (&now, (struct timezone *) NULL);
+  quagga_gettime (QUAGGA_CLK_MONOTONIC, &now);
 
   timerclear (&res);
   if (oi->thread_send_lsupdate)
@@ -1511,7 +1509,7 @@ config_write_ospf6_interface (struct vty *vty)
   return 0;
 }
 
-struct cmd_node interface_node =
+static struct cmd_node interface_node =
 {
   INTERFACE_NODE,
   "%s(config-if)# ",
