@@ -207,6 +207,14 @@ ospf6_lsa_age_current (struct ospf6_lsa *lsa)
     zlog_warn ("LSA: quagga_gettime failed, may fail LSA AGEs: %s",
                safe_strerror (errno));
 
+  if (ntohs (lsa->header->age) >= MAXAGE)
+    {
+      /* ospf6_lsa_premature_aging () sets age to MAXAGE; when using
+         relative time, we cannot compare against lsa birth time, so
+         we catch this special case here. */
+      lsa->header->age = htons (MAXAGE);
+      return MAXAGE;
+    }
   /* calculate age */
   ulage = now.tv_sec - lsa->birth.tv_sec;
 
@@ -239,7 +247,7 @@ ospf6_lsa_premature_aging (struct ospf6_lsa *lsa)
   THREAD_OFF (lsa->expire);
   THREAD_OFF (lsa->refresh);
 
-  memset (&lsa->birth, 0, sizeof (struct timeval));
+  lsa->header->age = htons (MAXAGE);
   thread_execute (master, ospf6_lsa_expire, lsa, 0);
 }
 
