@@ -114,11 +114,10 @@ ospf6_create (void)
 {
   struct ospf6 *o;
 
-  o = XMALLOC (MTYPE_OSPF6_TOP, sizeof (struct ospf6));
-  memset (o, 0, sizeof (struct ospf6));
+  o = XCALLOC (MTYPE_OSPF6_TOP, sizeof (struct ospf6));
 
   /* initialize */
-  gettimeofday (&o->starttime, (struct timezone *) NULL);
+  quagga_gettime (QUAGGA_CLK_MONOTONIC, &o->starttime);
   o->area_list = list_new ();
   o->area_list->cmp = ospf6_area_cmp;
   o->lsdb = ospf6_lsdb_create (o);
@@ -404,6 +403,13 @@ DEFUN (no_ospf6_interface_area,
       return CMD_SUCCESS;
     }
 
+  /* Verify Area */
+  if (oi->area == NULL)
+    {
+      vty_out (vty, "No such Area-ID: %s%s", argv[1], VNL);
+      return CMD_SUCCESS;
+    }
+
   if (oi->area->area_id != area_id)
     {
       vty_out (vty, "Wrong Area-ID: %s is attached to area %s%s",
@@ -441,7 +447,7 @@ ospf6_show (struct vty *vty, struct ospf6 *o)
            router_id, VNL);
 
   /* running time */
-  gettimeofday (&now, (struct timezone *)NULL);
+  quagga_gettime (QUAGGA_CLK_MONOTONIC, &now);
   timersub (&now, &o->starttime, &running);
   timerstring (&running, duration, sizeof (duration));
   vty_out (vty, " Running %s%s", duration, VNL);
@@ -651,7 +657,7 @@ config_write_ospf6 (struct vty *vty)
 }
 
 /* OSPF6 node structure. */
-struct cmd_node ospf6_node =
+static struct cmd_node ospf6_node =
 {
   OSPF6_NODE,
   "%s(config-ospf6)# ",
@@ -668,6 +674,7 @@ ospf6_top_init (void)
   install_element (VIEW_NODE, &show_ipv6_ospf6_cmd);
   install_element (ENABLE_NODE, &show_ipv6_ospf6_cmd);
   install_element (CONFIG_NODE, &router_ospf6_cmd);
+  install_element (CONFIG_NODE, &no_router_ospf6_cmd);
 
   install_element (VIEW_NODE, &show_ipv6_ospf6_route_cmd);
   install_element (VIEW_NODE, &show_ipv6_ospf6_route_detail_cmd);
@@ -690,7 +697,6 @@ ospf6_top_init (void)
   install_element (OSPF6_NODE, &ospf6_router_id_cmd);
   install_element (OSPF6_NODE, &ospf6_interface_area_cmd);
   install_element (OSPF6_NODE, &no_ospf6_interface_area_cmd);
-  install_element (OSPF6_NODE, &no_router_ospf6_cmd);
 }
 
 
