@@ -135,6 +135,7 @@ ospf_ase_complete_direct_routes (struct ospf_route *ro, struct in_addr nexthop)
 {
   struct listnode *node;
   struct ospf_path *op;
+  struct interface *ifp;
 
   for (ALL_LIST_ELEMENTS_RO (ro->paths, node, op))
     if (op->nexthop.s_addr == 0)
@@ -448,20 +449,23 @@ ospf_ase_calculate_route (struct ospf *ospf, struct ospf_lsa * lsa)
 
   /* if there is a Intra/Inter area route to the N
      do not install external route */
-  if ((rn = route_node_lookup (ospf->new_table,
-			       (struct prefix *) &p)) != NULL
-      && (rn->info != NULL))
+  if (rn = route_node_lookup (ospf->new_table,
+			      (struct prefix *) &p))
     {
+      route_unlock_node(rn);
+      if (rn->info == NULL)
+	zlog_info ("Route[External]: rn->info NULL");
       if (new)
 	ospf_route_free (new);
       return 0;
     }
-  
   /* Find a route to the same dest */
   /* If there is no route, create new one. */
-  if ((rn = route_node_lookup (ospf->new_external_route,
-			       (struct prefix *) &p)) == NULL 
-      || (or = rn->info) == NULL)
+  if (rn = route_node_lookup (ospf->new_external_route,
+			       (struct prefix *) &p))
+      route_unlock_node(rn);
+
+  if (!rn || (or = rn->info) == NULL)
     {
       if (IS_DEBUG_OSPF (lsa, LSA))
 	zlog_debug ("Route[External]: Adding a new route %s/%d",
@@ -590,6 +594,8 @@ ospf_ase_route_match_same (struct route_table *rt, struct prefix *prefix,
        
        if (! IPV4_ADDR_SAME (&op->nexthop, &newop->nexthop))
 	 return 0;
+       if (op->ifindex != newop->ifindex)
+	 return 0;
      }
    return 1;
 }
@@ -783,16 +789,18 @@ ospf_ase_incremental_update (struct ospf *ospf, struct ospf_lsa *lsa)
      (internal routes take precedence). */
   
   rn = route_node_lookup (ospf->new_table, (struct prefix *) &p);
-  if (rn && rn->info)
+  if (rn)
     {
       route_unlock_node (rn);
-      return;
+      if (rn->info)
+	return;
     }
 
   rn = route_node_lookup (ospf->external_lsas, (struct prefix *) &p);
   assert (rn && rn->info);
   lsas = rn->info;
-  
+  route_unlock_node (rn);
+
   for (ALL_LIST_ELEMENTS_RO (lsas, node, lsa))
     ospf_ase_calculate_route (ospf, lsa);
 
