@@ -118,8 +118,7 @@ rip_interface_new (void)
 {
   struct rip_interface *ri;
 
-  ri = XMALLOC (MTYPE_RIP_INTERFACE, sizeof (struct rip_interface));
-  memset (ri, 0, sizeof (struct rip_interface));
+  ri = XCALLOC (MTYPE_RIP_INTERFACE, sizeof (struct rip_interface));
 
   /* Default authentication type is simple password for Cisco
      compatibility. */
@@ -403,8 +402,9 @@ rip_interface_down (int command, struct zclient *zclient, zebra_size_t length)
   rip_if_down(ifp);
  
   if (IS_RIP_DEBUG_ZEBRA)
-    zlog_debug ("interface %s index %d flags %ld metric %d mtu %d is down",
-	       ifp->name, ifp->ifindex, ifp->flags, ifp->metric, ifp->mtu);
+    zlog_debug ("interface %s index %d flags %llx metric %d mtu %d is down",
+	       ifp->name, ifp->ifindex, (unsigned long long)ifp->flags,
+	       ifp->metric, ifp->mtu);
 
   return 0;
 }
@@ -423,7 +423,7 @@ rip_interface_up (int command, struct zclient *zclient, zebra_size_t length)
     return 0;
 
   if (IS_RIP_DEBUG_ZEBRA)
-    zlog_debug ("interface %s index %d flags %ld metric %d mtu %d is up",
+    zlog_debug ("interface %s index %d flags %lld metric %d mtu %d is up",
 	       ifp->name, ifp->ifindex, ifp->flags, ifp->metric, ifp->mtu);
 
   /* Check if this interface is RIP enabled or not.*/
@@ -447,7 +447,7 @@ rip_interface_add (int command, struct zclient *zclient, zebra_size_t length)
   ifp = zebra_interface_add_read (zclient->ibuf);
 
   if (IS_RIP_DEBUG_ZEBRA)
-    zlog_debug ("interface add %s index %d flags %ld metric %d mtu %d",
+    zlog_debug ("interface add %s index %d flags %lld metric %d mtu %d",
 	       ifp->name, ifp->ifindex, ifp->flags, ifp->metric, ifp->mtu);
 
   /* Check if this interface is RIP enabled or not.*/
@@ -486,7 +486,7 @@ rip_interface_delete (int command, struct zclient *zclient,
     rip_if_down(ifp);
   } 
   
-  zlog_info("interface delete %s index %d flags %ld metric %d mtu %d",
+  zlog_info("interface delete %s index %d flags %lld metric %d mtu %d",
 	    ifp->name, ifp->ifindex, ifp->flags, ifp->metric, ifp->mtu);  
   
   /* To support pseudo interface do not free interface structure.  */
@@ -591,7 +591,7 @@ rip_if_down(struct interface *ifp)
 	      {
 		rip_zebra_ipv4_delete ((struct prefix_ipv4 *) &rp->p,
 				       &rinfo->nexthop,
-				       rinfo->ifindex);
+				       rinfo->metric);
 
 		rip_redistribute_delete (rinfo->type,rinfo->sub_type,
 					 (struct prefix_ipv4 *)&rp->p,
@@ -2052,7 +2052,7 @@ config_write_rip_network (struct vty *vty, int config_mode)
   return 0;
 }
 
-struct cmd_node interface_node =
+static struct cmd_node interface_node =
 {
   INTERFACE_NODE,
   "%s(config-if)# ",
